@@ -2,7 +2,7 @@
 #############################################################################
 # arc.sh -- local Argile compiler wrapping script
 #
-#   Copyright (C) 2009,2010,2011 the Argile authors
+#   Copyright (C) 2009,2010,2011,2014 the Argile authors
 #
 #   This software is free software: you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -30,38 +30,19 @@
 # script name
 self=$(basename "$0")
 
-# build dir
-dir="$1" ; shift
-
 # arc
-arc="$dir/arc"
+arc="$1/arc"
 
-# libargile.so
-lib="$dir/libargile.so"
-
-# std.so
-std="$dir/std.so"
-
-local_arc_is_ready() {
-    [ -d "$dir" ] || return 1
-    [ -x "$arc" ] || return 1
-    [ -e "$lib" ] || return 1
-    [ -e "$std" ] || return 1
-    return 0
-}
+shift
 
 echo_exec() {
-    echo "$self: $*"
+    echo "$*"
     exec "$@"
 }
 
-# exec
-if local_arc_is_ready; then
-    export ARGILE_SOM_PATH="$dir:$ARGILE_SOM_PATH"
-    export LD_LIBRARY_PATH="$dir:$LD_LIBRARY_PATH"
-    export LD_PRELOAD="$lib"
+if [ -x "$arc" ]
+then
     echo_exec "$arc" "$@"
-else
-    # trying external argile compiler
+else # trying external argile compiler
     echo_exec arc "$@"
 fi
